#define _GLIBCXX_DEBUG

#include <iostream>
#include <cmath>
#include <cassert>
#include <vector>
#include <map>
#include <set>
#include <utility>
#include <tuple>
#include <algorithm>
#include <string>
#include <unordered_set>
#include <unordered_map>

#define int long long
#define double long double

using namespace std;

const double EPS = 0.000000001;

class SegmentTree {
public:
    int n;
    vector<int> a;

    SegmentTree(int sz) {
        n = sz;
        a.resize(4 * n);
    }

    int get(int v, int vl, int vr, int l, int r) {
        if(l == vl && r == vr) {
            return a[v];
        }
        int vm = (vl + vr) / 2;
        if(r <= vm) {
            return get(v * 2, vl, vm, l, r);
        } else if(l >= vm) {
            return get(v * 2 + 1, vm, vr, l, r);
        } else {
            return get(v * 2, vl, vm, l, vm) + get(v * 2 + 1, vm, vr, vm, r);
        }
    }
    int get(int l, int r) {
        return get(1, 0, n, l, r);
    }
    int get(int i) {
        return get(i, i + 1);
    }

    void set(int v, int vl, int vr, int i, int x) {
        if(vr - vl == 1) {
            a[v] = x;
        } else {
            int vm = (vl + vr) / 2;
            if(i < vm) {
                set(v * 2, vl, vm, i, x);
            } else {
                set(v * 2 + 1, vm, vr, i, x);
            }
            a[v] = a[v * 2] + a[v * 2 + 1];
        }
    }
    void set(int i, int x) {
        set(1, 0, n, i, x);
    }
};


class Vertex {
public:
    int sz;
    int y;
    int val;
    Vertex* left;
    Vertex* right;

    Vertex(int value) {
        sz = 1;
        y = rand();
        val = value;
        left = nullptr;
        right = nullptr;
    }

    void pull() {
        sz = (left ? left->sz : 0) + 1 + (right ? right->sz : 0);
    }
};


class Treap {
public:
    Vertex* root;

    Treap() {
        root = nullptr;
    }

    Vertex* merge(Vertex* a, Vertex* b) {
        if(a == nullptr) {
            return b;
        }
        if(b == nullptr) {
            return a;
        }
        if(a->y > b->y) {
            a->right = merge(a->right, b);
            a->pull();
            return a;
        } else {
            b->left = merge(a, b->left);
            b->pull();
            return b;
        }
    }

    pair<Vertex*, Vertex*> split(Vertex* v, int c) {
        if(v == nullptr) {
            return make_pair(nullptr, nullptr);
        }
        if((v->left ? v->left->sz : 0) >= c) {
            pair<Vertex*, Vertex*> p = split(v->left, c);
            v->left = p.second;
            v->pull();
            return make_pair(p.first, v);
        } else {
            pair<Vertex*, Vertex*> p = split(v->right, c - 1 - (v->left ? v->left->sz : 0));
            v->right = p.first;
            v->pull();
            return make_pair(v, p.second);
        }
    }

    void insert(int i, int val) {
        auto v = new Vertex(val);
        pair<Vertex*, Vertex*> p = split(root, i);
        root = merge(p.first, merge(v, p.second));
    }

    Vertex* erase(int i) {
        pair<Vertex*, Vertex*> p = split(root, i);
        pair<Vertex*, Vertex*> p2 = split(p.second, 1);
        root = merge(p.first, p2.second);
        return p2.first;
    }

    int peek(int i) {
        pair<Vertex*, Vertex*> p = split(root, i);
        pair<Vertex*, Vertex*> p2 = split(p.second, 1);
        assert(p2.first != nullptr);
        int val = p2.first->val;
        root = merge(p.first, merge(p2.first, p2.second));
        return val;
    }

    int size() {
        return root ? root->sz : 0;
    }
};


class Point {
public:
    double x, y;
    bool ex;
    Point(double xx, double yy) {
        x = xx;
        y = yy;
        ex = true;
    }
    Point() {
        ex = false;
    }
    operator bool() {
        return ex;
    }
    double dist(Point p) {
        double dx = x - p.x;
        double dy = y - p.y;
        return sqrt(dx * dx + dy * dy);
    }
};


class Vector {
public:
    double x, y;
    Vector(double xx, double yy) {
        x = xx;
        y = yy;
    }
    Vector(Point a, Point b) {
        x = b.x - a.x;
        y = b.y - a.y;
    }
    Vector operator-() {
        return Vector(-x, -y);
    }

    void normalize() {
        double coeff = sqrt(x * x + y * y);
        x /= coeff;
        y /= coeff;
    }

    Vector normalized() {
        Vector v = *this;
        v.normalize();
        return v;
    }

    double operator* (Vector v) {
        return x * v.x + y * v.y;
    }
    double operator% (Vector v) {
        return x * v.y - y * v.x;
    }
};

Point operator+ (Point a, Vector v) {
    return Point(a.x + v.x, a.y + v.y);
}

Point operator- (Point a, Vector v) {
    return Point(a.x - v.x, a.y - v.y);
}


class Line {
public:
    double a, b, c;
    Line(double aa, double bb, double cc) {
        a = aa;
        b = bb;
        c = cc;
    }
    Line(Point p1, Point p2) {
        a = p1.y - p2.y;
        b = p2.x - p1.x;
        c = -a * p1.x - b * p1.y;
    }

    void normalize() {
        double coeff = sqrt(a * a + b * b);
        a /= coeff;
        b /= coeff;
        c /= coeff;
    }
    Line normalized() {
        Line l = *this;
        l.normalize();
        return l;
    }

    double operator() (Point p) {
        return a * p.x + b * p.y + c;
    }
    Point operator& (Line l) {
        if(abs(a * l.b - l.a * b) < EPS) {
            return Point();
        }
        double x = (l.c * b - c * l.b) / (a * l.b - l.a * b);
        double y = (l.c * a - c * l.a) / (b * l.a - l.b * a);
        return Point(x, y);
    }
};


class Segment {
public:
    Point a, b;
    Segment(Point aa, Point bb) {
        a = aa;
        b = bb;
    }
    Point operator& (Segment s) {
        Point p = Line(a, b) & Line(s.a, s.b);
        if(!p) {
            return p;
        }
        if(!(
             min(a.x, b.x) - EPS < p.x && p.x < max(a.x, b.x) + EPS && min(a.y, b.y) - EPS < p.y && p.y < max(a.y, b.y) + EPS &&
             min(s.a.x, s.b.x) - EPS < p.x && p.x < max(s.a.x, s.b.x) + EPS && min(s.a.y, s.b.y) - EPS < p.y && p.y < max(s.a.y, s.b.y) + EPS
        )) {
            return Point();
        }
        return p;
    }
};


signed main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);

    int n;
    cin >> n;

    map<int, set< pair<int, int> > > xx, yy;
    vector< pair<int, int> > pp;
    for(int i = 0; i < n; i++) {
        int x, y;
        cin >> x >> y;
        xx[y].emplace(x, i);
        yy[x].emplace(y, i);
        pp.emplace_back(x, y);
    }

    int extremal = 0, internal = 0;
    vector<bool> is_extremal(n), is_internal(n);
    for(int i = 0; i < n; i++) {
        int x = pp[i].first;
        int y = pp[i].second;
        auto it = xx[y].find(make_pair(x, i));
        auto it2 = yy[x].find(make_pair(y, i));
        if((it == xx[y].begin() || it == --xx[y].end()) && (it2 == yy[x].begin() || it2 == --yy[x].end())) {
            extremal++;
            is_extremal[i] = true;
        }
        if(it != xx[y].begin() && it != --xx[y].end() && it2 != yy[x].begin() && it2 != --yy[x].end()) {
            internal++;
            is_internal[i] = true;
        }
    }

    cout << extremal << " " << internal << endl;

    int q;
    cin >> q;
    is_extremal.resize(n + q);
    is_internal.resize(n + q);
    for(int i = 0; i < q; i++) {
        int t, x, y;
        cin >> t >> x >> y;

        if(t == 1) {
            xx[y].emplace(x, n + i);
            yy[x].emplace(y, n + i);
        } else if(t == 2) {
            auto it = xx[y].lower_bound(make_pair(x, 0LL));
            auto it2 = yy[x].lower_bound(make_pair(y, 0LL));
            auto j = it->second;
            xx[y].erase(it);
            yy[x].erase(it2);
            if(is_extremal[j]) {
                is_extremal[j] = false;
                extremal--;
            }
            if(is_internal[j]) {
                is_internal[j] = false;
                internal--;
            }
        }

        auto it = xx[y].lower_bound(make_pair(x, 0LL));
        auto it2 = yy[x].lower_bound(make_pair(y, 0LL));

        auto it_st = it;
        for(int i = 0; i < 10 && it_st != xx[y].begin(); i++) {
            it_st--;
        }
        auto it_end = it;
        for(int i = 0; i < 10 && it_end != xx[y].end(); i++) {
            it_end++;
        }
        while(it_st != it_end) {
            auto p = *it_st++;
            int jx = p.first;
            int jy = y;
            int j = p.second;
            if(is_extremal[j]) {
                extremal--;
            }
            if(is_internal[j]) {
                internal--;
            }

            auto it = xx[jy].find(make_pair(jx, j));
            auto it2 = yy[jx].find(make_pair(jy, j));

            is_extremal[j] = (it == xx[jy].begin() || it == --xx[jy].end()) && (it2 == yy[jx].begin() || it2 == --yy[jx].end());
            extremal += is_extremal[j];

            is_internal[j] = it != xx[jy].begin() && it != --xx[jy].end() && it2 != yy[jx].begin() && it2 != --yy[jx].end();
            internal += is_internal[j];
        }

        it_st = it2;
        for(int i = 0; i < 10 && it_st != yy[x].begin(); i++) {
            it_st--;
        }
        it_end = it2;
        for(int i = 0; i < 10 && it_end != yy[x].end(); i++) {
            it_end++;
        }
        while(it_st != it_end) {
            auto p = *it_st++;
            int jx = x;
            int jy = p.first;
            int j = p.second;
            if(is_extremal[j]) {
                extremal--;
            }
            if(is_internal[j]) {
                internal--;
            }

            auto it = xx[jy].find(make_pair(jx, j));
            auto it2 = yy[jx].find(make_pair(jy, j));

            is_extremal[j] = (it == xx[jy].begin() || it == --xx[jy].end()) && (it2 == yy[jx].begin() || it2 == --yy[jx].end());
            extremal += is_extremal[j];

            is_internal[j] = it != xx[jy].begin() && it != --xx[jy].end() && it2 != yy[jx].begin() && it2 != --yy[jx].end();
            internal += is_internal[j];
        }

        cout << extremal << " " << internal << endl;
    }

    return 0;
}

/*
10
1 4
2 1
1 2
3 4
4 2
2 2
1 1
3 1
3 2
4 3
3
1 4 4
2 1 1
1 2 3
*/
