#include <iostream>
#include <cmath>
#include <cassert>
#include <vector>
#include <map>
#include <set>
#include <utility>
#include <tuple>
#include <algorithm>
#include <string>
#include <unordered_set>
#include <unordered_map>

#define double long double

using namespace std;

const double EPS = 0.000000001;

class SegmentTree {
public:
    int n;
    vector<int> a;

    SegmentTree(int sz) {
        n = sz;
        a.resize(4 * n);
    }

    int get(int v, int vl, int vr, int l, int r) {
        if(l == vl && r == vr) {
            return a[v];
        }
        int vm = (vl + vr) / 2;
        if(r <= vm) {
            return get(v * 2, vl, vm, l, r);
        } else if(l >= vm) {
            return get(v * 2 + 1, vm, vr, l, r);
        } else {
            return get(v * 2, vl, vm, l, vm) + get(v * 2 + 1, vm, vr, vm, r);
        }
    }
    int get(int l, int r) {
        return get(1, 0, n, l, r);
    }
    int get(int i) {
        return get(i, i + 1);
    }

    void set(int v, int vl, int vr, int i, int x) {
        if(vr - vl == 1) {
            a[v] = x;
        } else {
            int vm = (vl + vr) / 2;
            if(i < vm) {
                set(v * 2, vl, vm, i, x);
            } else {
                set(v * 2 + 1, vm, vr, i, x);
            }
            a[v] = a[v * 2] + a[v * 2 + 1];
        }
    }
    void set(int i, int x) {
        set(1, 0, n, i, x);
    }
};


class Vertex {
public:
    int sz;
    int y;
    int val;
    Vertex* left;
    Vertex* right;

    Vertex(int value) {
        sz = 1;
        y = rand();
        val = value;
        left = nullptr;
        right = nullptr;
    }

    void pull() {
        sz = (left ? left->sz : 0) + 1 + (right ? right->sz : 0);
    }
};


class Treap {
public:
    Vertex* root;

    Treap() {
        root = nullptr;
    }

    Vertex* merge(Vertex* a, Vertex* b) {
        if(a == nullptr) {
            return b;
        }
        if(b == nullptr) {
            return a;
        }
        if(a->y > b->y) {
            a->right = merge(a->right, b);
            a->pull();
            return a;
        } else {
            b->left = merge(a, b->left);
            b->pull();
            return b;
        }
    }

    pair<Vertex*, Vertex*> split(Vertex* v, int c) {
        if(v == nullptr) {
            return make_pair(nullptr, nullptr);
        }
        if((v->left ? v->left->sz : 0) >= c) {
            pair<Vertex*, Vertex*> p = split(v->left, c);
            v->left = p.second;
            v->pull();
            return make_pair(p.first, v);
        } else {
            pair<Vertex*, Vertex*> p = split(v->right, c - 1 - (v->left ? v->left->sz : 0));
            v->right = p.first;
            v->pull();
            return make_pair(v, p.second);
        }
    }

    void insert(int i, int val) {
        auto v = new Vertex(val);
        pair<Vertex*, Vertex*> p = split(root, i);
        root = merge(p.first, merge(v, p.second));
    }

    Vertex* erase(int i) {
        pair<Vertex*, Vertex*> p = split(root, i);
        pair<Vertex*, Vertex*> p2 = split(p.second, 1);
        root = merge(p.first, p2.second);
        return p2.first;
    }

    int peek(int i) {
        pair<Vertex*, Vertex*> p = split(root, i);
        pair<Vertex*, Vertex*> p2 = split(p.second, 1);
        assert(p2.first != nullptr);
        int val = p2.first->val;
        root = merge(p.first, merge(p2.first, p2.second));
        return val;
    }

    int size() {
        return root ? root->sz : 0;
    }
};


class Point {
public:
    double x, y;
    bool ex;
    Point(double xx, double yy) {
        x = xx;
        y = yy;
        ex = true;
    }
    Point() {
        ex = false;
    }
    operator bool() {
        return ex;
    }
    double dist(Point p) {
        double dx = x - p.x;
        double dy = y - p.y;
        return sqrt(dx * dx + dy * dy);
    }
};


class Vector {
public:
    double x, y;
    Vector(double xx, double yy) {
        x = xx;
        y = yy;
    }
    Vector(Point a, Point b) {
        x = b.x - a.x;
        y = b.y - a.y;
    }
    Vector operator-() {
        return Vector(-x, -y);
    }

    void normalize() {
        double coeff = sqrt(x * x + y * y);
        x /= coeff;
        y /= coeff;
    }

    Vector normalized() {
        Vector v = *this;
        v.normalize();
        return v;
    }

    double operator* (Vector v) {
        return x * v.x + y * v.y;
    }
    double operator% (Vector v) {
        return x * v.y - y * v.x;
    }
};

Point operator+ (Point a, Vector v) {
    return Point(a.x + v.x, a.y + v.y);
}

Point operator- (Point a, Vector v) {
    return Point(a.x - v.x, a.y - v.y);
}


class Line {
public:
    double a, b, c;
    Line(double aa, double bb, double cc) {
        a = aa;
        b = bb;
        c = cc;
    }
    Line(Point p1, Point p2) {
        a = p1.y - p2.y;
        b = p2.x - p1.x;
        c = -a * p1.x - b * p1.y;
    }

    void normalize() {
        double coeff = sqrt(a * a + b * b);
        a /= coeff;
        b /= coeff;
        c /= coeff;
    }
    Line normalized() {
        Line l = *this;
        l.normalize();
        return l;
    }

    double operator() (Point p) {
        return a * p.x + b * p.y + c;
    }
    Point operator& (Line l) {
        if(abs(a * l.b - l.a * b) < EPS) {
            return Point();
        }
        double x = (l.c * b - c * l.b) / (a * l.b - l.a * b);
        double y = (l.c * a - c * l.a) / (b * l.a - l.b * a);
        return Point(x, y);
    }
};


class Segment {
public:
    Point a, b;
    Segment(Point aa, Point bb) {
        a = aa;
        b = bb;
    }
    Point operator& (Segment s) {
        Point p = Line(a, b) & Line(s.a, s.b);
        if(!p) {
            return p;
        }
        if(!(
             min(a.x, b.x) - EPS < p.x && p.x < max(a.x, b.x) + EPS && min(a.y, b.y) - EPS < p.y && p.y < max(a.y, b.y) + EPS &&
             min(s.a.x, s.b.x) - EPS < p.x && p.x < max(s.a.x, s.b.x) + EPS && min(s.a.y, s.b.y) - EPS < p.y && p.y < max(s.a.y, s.b.y) + EPS
        )) {
            return Point();
        }
        return p;
    }
};


const int MAXN = 1000000;
const int MAXM = 1000000;

int n, m;
vector< pair<int, int> > adj[MAXN];
pair<int, int> edges[MAXM];
bool dpe[MAXM];
bool used[MAXM];

void dfs(int e) {
    used[e] = true;

    int u = edges[e].second;
    for(auto p: adj[u]) {
        if(p.second != (e ^ 1)) {
            if(!used[p.second]) {
                dfs(p.second);
            }
            dpe[e] = dpe[e] || !dpe[p.second];
        }
    }
}

signed main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);

    cin >> n >> m;
    for(int i = 0; i < m; i++) {
        int u, v;
        cin >> u >> v;
        u--; v--;
        adj[u].emplace_back(v, i * 2);
        adj[v].emplace_back(u, i * 2 + 1);
        edges[i * 2] = make_pair(u, v);
        edges[i * 2 + 1] = make_pair(v, u);
    }

    for(int i = 0; i < m * 2; i++) {
        dpe[i] = false;
        used[i] = false;
    }
    for(int i = 0; i < m * 2; i++) {
        if(!used[i]) {
            dfs(i);
        }
    }

    for(int u = 0; u < n; u++) {
        bool ans = true;
        for(auto p: adj[u]) {
            ans = ans && dpe[p.second];
        }
        printf("%d", ans ? 1 : 0);
    }

    return 0;
}
